# rf-linkbudget

<!-- https://packaging.python.org/tutorials/packaging-projects/ -->

The current Documentation is found under this link : <https://rf-linkbudget.readthedocs.io/en/latest/index.html>

## Abstract
RF-LinkBudget is a software package to aid RF Hardware Developer in defining and comparing LinkBudget’s of RF Ciruits.
It calculates key parameter’s like cumulative Noise Figure, cumulates Gain, Intermodulation Signal Amplitudes and so on.

## Changelog

# 1.1.0
Changed Attenuator OIP3 to IIP3 value.
This change breaks old scripts!

# 1.0.2
Added `Filter` Component
